Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1817)

Unified Diff: chrome/android/javatests/src/org/chromium/chrome/browser/notifications/NotificationTestBase.java

Issue 1919183003: Rename NotificationUIManager to NotificationPlatformBridge (1/2) (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/javatests/src/org/chromium/chrome/browser/notifications/NotificationTestBase.java
diff --git a/chrome/android/javatests/src/org/chromium/chrome/browser/notifications/NotificationTestBase.java b/chrome/android/javatests/src/org/chromium/chrome/browser/notifications/NotificationTestBase.java
index 76a7d978a4e9bb2c60a95911602569ee1194f235..be453869a58319a992072185f066d417f65c467f 100644
--- a/chrome/android/javatests/src/org/chromium/chrome/browser/notifications/NotificationTestBase.java
+++ b/chrome/android/javatests/src/org/chromium/chrome/browser/notifications/NotificationTestBase.java
@@ -129,16 +129,16 @@ public class NotificationTestBase extends ChromeTabbedActivityTestBase {
@Override
public void startMainActivity() throws InterruptedException {
// The NotificationUIManager must be overriden prior to the browser process starting.
mMockNotificationManager = new MockNotificationManagerProxy();
- NotificationUIManager.overrideNotificationManagerForTesting(mMockNotificationManager);
+ NotificationPlatformBridge.overrideNotificationManagerForTesting(mMockNotificationManager);
startMainActivityFromLauncher();
}
@Override
protected void tearDown() throws Exception {
- NotificationUIManager.overrideNotificationManagerForTesting(null);
+ NotificationPlatformBridge.overrideNotificationManagerForTesting(null);
mTestServer.stopAndDestroyServer();
super.tearDown();
}
@@ -129,16 +129,16 @@ public class NotificationTestBase extends ChromeTabbedActivityTestBase {
public void startMainActivity() throws InterruptedException {
- // The NotificationUIManager must be overriden prior to the browser process starting.
+ // The NotificationPlatformBridge must be overriden prior to the browser process starting.
mMockNotificationManager = new MockNotificationManagerProxy();

Powered by Google App Engine
This is Rietveld 408576698